@@ -22,8 +22,8 @@
 /* needed for print functions to get y coordinates and
  * interval for each output, yeah I know using global variables
  * sucks, but it's PITA to use local ones here */
-int line = 0;
-int interval = 2;
+static int line = 0;
+static int interval = 2;
 
 static void
 usage (void){
@@ -150,6 +150,7 @@ print_ac(const int ac_s, global_t *global, const int t, const int not_f){
 	adapter_t *ac = &global->adapt;
 
 	if(!ac) return;
+	read_acpi_acstate(global);
 	if(t){
 		if(ac_s == SUCCESS && ac->ac_state == P_BATT)
 			printf("| ac = off-line ");
@@ -502,7 +503,7 @@ main(int argc, char **argv){
 				options |= AC_F;
 				break;
 			case 'v':
-				puts ("YACPI " VERSION " by Nico Golde - Released: 18.03.2007\n");
+				puts ("YACPI " VERSION " by Nico Golde - Released: 09.08.2007\n");
 				return 0;
 				break;
 			case 'b':
